var builder = function builder(eventName) {
  return function (node, func) {
    return new Promise(function (resolve, reject) {
      // reject for invalid node
      if (!(node instanceof window.HTMLElement || node instanceof window.SVGElement)) {
        return reject(new Error('tail-end: an HTML or SVG element is required.'));
      } // create the event handler


      var handler = function handler(event) {
        // unbind the handler
        node.removeEventListener(eventName, handler); // resolve the (now clean) node

        return resolve(node);
      }; // bind the handler


      node.addEventListener(eventName, handler); // if it exists, call the function passing in the node

      if (typeof func === 'function') {
        window.requestAnimationFrame(function () {
          return func(node);
        });
      }
    });
  };
};

var animationEnd = builder('animationend');
var transitionEnd = builder('transitionend');

export { animationEnd, transitionEnd };
